==> Euphorie-9.0.17.tar.gz: Euphorie-9.0.17/src/euphorie/content/api/tests/test_errors.py <==
from euphorie.deployment.tests.functional import EuphorieFunctionalTestCase
from Products.Five.testbrowser import Browser


class GenericErrorTests(EuphorieFunctionalTestCase):
    def test_View(self):
        import json
        import mock
        with mock.patch('euphorie.content.api.entry.View.do_GET',
                sideEffect=RuntimeError):
            browser = Browser()
            browser.raiseHttpErrors = False
            browser.open('http://nohost/plone/api')
            self.assertTrue(browser.headers['Status'].startswith('500'))
            response = json.loads(browser.contents)
            self.assertEqual(
                    set(response),
                    set(['type', 'message']))
            self.assertEqual(response['type'], 'error')
            self.assertEqual(response['message'], u'An unknown error occurred.')


class NotFoundViewTests(EuphorieFunctionalTestCase):
    def test_404_handled(self):
        import json
        browser = Browser()
        browser.raiseHttpErrors = False
        browser.open('http://nohost/plone/api/unknown')
        self.assertTrue(browser.headers['Status'].startswith('404'))
        self.assertEqual(browser.headers['Content-Type'], 'application/json')
        response = json.loads(browser.contents)
        self.assertEqual(
                set(response),
                set(['type', 'message']))
        self.assertEqual(response['type'], 'error')
        self.assertEqual(response['message'], 'Unknown resource requested.')


class UnauthorizedViewTests(EuphorieFunctionalTestCase):
    def test_view(self):
        import json
        browser = Browser()
        browser.raiseHttpErrors = False
        browser.open('http://nohost/plone/api/countries')
        self.assertTrue(browser.headers['Status'].startswith('401'))
        self.assertEqual(browser.headers['Content-Type'], 'application/json')
        response = json.loads(browser.contents)
        self.assertEqual(
                set(response),
                set(['type', 'message']))
        self.assertEqual(response['type'], 'error')
        self.assertEqual(response['message'], 'Access denied.')

==> Euphorie-11.0.4.tar.gz: Euphorie-11.0.4/src/euphorie/content/api/tests/test_errors.py <==
# coding=utf-8
from euphorie.testing import EuphorieFunctionalTestCase

import json
import mock


class GenericErrorTests(EuphorieFunctionalTestCase):

    def test_View(self):
        with mock.patch(
            'euphorie.content.api.entry.View.do_GET', sideEffect=RuntimeError
        ):
            browser = self.get_browser()
            browser.raiseHttpErrors = False
            browser.open('http://nohost/plone/api')
            self.assertTrue(browser.headers['Status'].startswith('500'))
            response = json.loads(browser.contents)
            self.assertEqual(set(response), set(['type', 'message']))
            self.assertEqual(response['type'], 'error')
            self.assertEqual(
                response['message'], u'An unknown error occurred.'
            )


class NotFoundViewTests(EuphorieFunctionalTestCase):

    def test_404_handled(self):
        browser = self.get_browser()
        browser.raiseHttpErrors = False
        browser.open('http://nohost/plone/api/unknown')
        self.assertTrue(browser.headers['Status'].startswith('404'))
        self.assertEqual(browser.headers['Content-Type'], 'application/json')
        response = json.loads(browser.contents)
        self.assertEqual(set(response), set(['type', 'message']))
        self.assertEqual(response['type'], 'error')
        self.assertEqual(response['message'], 'Unknown resource requested.')


class UnauthorizedViewTests(EuphorieFunctionalTestCase):

    def test_view(self):
        browser = self.get_browser()
        browser.raiseHttpErrors = False
        browser.open('http://nohost/plone/api/countries')
        self.assertTrue(browser.headers['Status'].startswith('401'))
        self.assertEqual(browser.headers['Content-Type'], 'application/json')
        response = json.loads(browser.contents)
        self.assertEqual(set(response), set(['type', 'message']))
        self.assertEqual(response['type'], 'error')
        self.assertEqual(response['message'], 'Access denied.')
